@@ -9,9 +9,9 @@
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   it under the terms of the GNU Lesser General Public License as        *
+ *   published by the Free Software Foundation; either version 2 of the    *
+ *   License, or (at your option) any later version.                       *
  *                                                                         *
  ***************************************************************************/
 
@@ -285,6 +285,11 @@ namespace Qyoto
 		/// This hashtable has the class types as keys, and QMetaObjects as values
 		static Dictionary<Type, QMetaObject> metaObjects = new Dictionary<Type, QMetaObject> ();
 		
+		public static void Cleanup() {
+			SmokeMarshallers.ConvertRefs();
+			SetApplicationTerminated();
+		}
+		
 		public static uint GetCPPEnumValue(string c, string value) {
 			Type t = Type.GetType("Qyoto." + c, false);
 			if (t == null) {
@@ -336,11 +341,16 @@ namespace Qyoto
 			}
 
 			if (type.IsGenericType) {
-				return "FIXME: <generic type here>";
+				Type[] args = type.GetGenericArguments();
+				if (type.FullName.StartsWith("System.Collections.Generic.List`1")) {
+					return "QList<" + GetPrimitiveString(args[0]) + ">";
+				} else if (type.FullName.StartsWith("System.Collections.Generic.Dictionary`2")) {
+					return "QMap<" + GetPrimitiveString(args[0]) + ", " + GetPrimitiveString(args[1]) + ">";
+				}
 			}
 
-			if (typeString.StartsWith("Qyoto.")) {
-				typeString = typeString.Replace("Qyoto.", "");
+			if (SmokeMarshallers.IsSmokeClass(type)) {
+				typeString = SmokeMarshallers.SmokeClassName(type);
 			}
 			
 			// pointer types
