@@ -22,6 +22,30 @@
 require 'Qt'
 
 module KDE
+	def KDE.i18n(text, *args)
+		str = ki18n(text)
+		args.inject(str) { |str, arg| str = str.subs(arg) }
+		return str.toString
+	end
+
+	def KDE.i18nc(context, text, *args)
+		str = ki18nc(context, text)
+		args.inject(str) { |str, arg| str = str.subs(arg) }
+		return str.toString
+	end
+
+	def KDE.i18np(singular, plural, *args)
+		str = ki18np(singular, plural)
+		args.inject(str) { |str, arg| str = str.subs(arg) }
+		return str.toString
+	end
+
+	def KDE.i18ncp(context, singular, plural, *args)
+		str = ki18ncp(context, singular, plural)
+		args.inject(str) { |str, arg| str = str.subs(arg) }
+		return str.toString
+	end
+
 	class Application < Qt::Base
 		def initialize(*k)
 			super
@@ -294,7 +318,7 @@ module KDE
 			method_missing(:name, *args)
 		end
 
-		def readEntry(key, default)
+		def readEntry(key, default = nil)
 			if default.kind_of?(String) || default.kind_of?(Qt::Variant)
 				return super(key, default)
 			else
@@ -302,6 +326,10 @@ module KDE
 			end
 		end
 
+		def read_entry(key, default = nil)
+			readEntry(key, default)
+		end
+
 		def writeEntry(key, value, pFlags = KDE::ConfigBase::Normal)
 			if value.kind_of?(String) || value.kind_of?(Qt::Variant)
 				super(key, value, pFlags)
@@ -309,6 +337,10 @@ module KDE
 				super(key, Qt::Variant.new(value), pFlags)
 			end
 		end
+
+		def write_entry(key, value, pFlags = KDE::ConfigBase::Normal)
+			writeEntry(key, value, pFlags)
+		end
 	end
 
 	class Dialog < Qt::Base
