@@ -2,7 +2,7 @@
 
 #include <dcopclient.h>
 #include <dcopobject.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kstdaction.h>
 #include <kaction.h>
 #include <kmainwindow.h>
